==> haskell-io-storage-0.3-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-io-storage.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 io-storage
version:              0.3
visibility:           public
id:                   io-storage-0.3-AK0jChG7QLrF2LpXoYjRhr
key:                  io-storage-0.3-AK0jChG7QLrF2LpXoYjRhr
license:              BSD-3-Clause
copyright:            (c) 2009 Will Donnelly
maintainer:           Will Donnelly <will.donnelly@gmail.com>
author:               Will Donnelly
stability:            alpha
homepage:             http://github.com/willdonnelly/io-storage
synopsis:             A key-value store in the IO monad.
description:
    This library allows an application to extend the '\''global state'\''
    hidden inside the IO monad with semi-arbitrary data. Data is
    required to be '\''Typeable'\''. The library provides an essentially
    unbounded number of key-value stores indexed by strings, with
    each key within the stores also being a string.

category:             Database, Data, System
abi:                  106781b667e405e2c5792e2ca5e9885b
exposed:              True
exposed-modules:      System.IO.Storage
import-dirs:          /usr/lib/ghc-9.2.8/site-local/io-storage-0.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/io-storage-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-io-storage
hs-libraries:         HSio-storage-0.3-AK0jChG7QLrF2LpXoYjRhr
depends:              base-4.16.4.0 containers-0.6.5.1
haddock-interfaces:   /usr/share/doc/haskell-io-storage/html/io-storage.haddock
haddock-html:         /usr/share/doc/haskell-io-storage/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-io-storage-0.3-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-io-storage.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 io-storage
version:              0.3
visibility:           public
id:                   io-storage-0.3-82gGraAKqq85Lwx0MtGRVP
key:                  io-storage-0.3-82gGraAKqq85Lwx0MtGRVP
license:              BSD-3-Clause
copyright:            (c) 2009 Will Donnelly
maintainer:           Will Donnelly <will.donnelly@gmail.com>
author:               Will Donnelly
stability:            alpha
homepage:             http://github.com/willdonnelly/io-storage
synopsis:             A key-value store in the IO monad.
description:
    This library allows an application to extend the '\''global state'\''
    hidden inside the IO monad with semi-arbitrary data. Data is
    required to be '\''Typeable'\''. The library provides an essentially
    unbounded number of key-value stores indexed by strings, with
    each key within the stores also being a string.

category:             Database, Data, System
abi:                  bd641b978dbcbfc040a52d2479bebdc8
exposed:              True
exposed-modules:      System.IO.Storage
import-dirs:          /usr/lib/ghc-9.4.8/site-local/io-storage-0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/io-storage-0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/io-storage-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-io-storage
hs-libraries:         HSio-storage-0.3-82gGraAKqq85Lwx0MtGRVP
depends:              base-4.17.2.1 containers-0.6.7
haddock-interfaces:   /usr/share/doc/haskell-io-storage/html/io-storage.haddock
haddock-html:         /usr/share/doc/haskell-io-storage/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
